package org.fax4j.spi.email;

import java.util.Properties;
import org.fax4j.spi.email.AbstractMailFaxClientSpi.FaxClientSpiConfigurationConstants;
import org.fax4j.util.AbstractFax4JConnectionFactory;

/**
 * Provides partial implementation of the mail connection factory.
 * 
 * @author 	Sagie Gur-Ari
 * @version 1.01
 * @since	0.39a
 */
public abstract class AbstractMailConnectionFactory extends AbstractFax4JConnectionFactory<MailResourcesHolder,AbstractMailFaxClientSpi> implements MailConnectionFactory
{
	/**The mail connection properties*/
	protected Properties mailConnectionProperties;
	/**The mail connection user name*/
	protected String userName;
	/**The mail connection password*/
	protected String password;
	/**The transport protocol*/
	protected String transportProtocol;
	/**The transport host*/
	protected String transportHost;
	/**The transport port*/
	protected int transportPort;

	/**
	 * This is the class constructor.
	 */
	public AbstractMailConnectionFactory()
	{
		super();
	}

	/**
	 * This function initializes the connection factory.
	 */
	@Override
	protected void initializeImpl()
	{
		//create properties from configuration (all javax mail properties will be defined in the fax4j properties)
		this.mailConnectionProperties=new Properties();
		this.mailConnectionProperties.putAll(this.ownerFaxClientSpi.getMailConfiguration());
		
		//get user/password values
		this.userName=this.ownerFaxClientSpi.getConfigurationValue(FaxClientSpiConfigurationConstants.USER_NAME_PROPERTY_KEY);
		this.password=this.ownerFaxClientSpi.getConfigurationValue(FaxClientSpiConfigurationConstants.PASSWORD_PROPERTY_KEY);

		//get transport protocol
		this.transportProtocol=this.ownerFaxClientSpi.getConfigurationValue("mail.transport.protocol");
		if(this.transportProtocol==null)
		{
			this.transportProtocol="smtp";
		}

		//get transport host
		this.transportHost=this.ownerFaxClientSpi.getConfigurationValue("mail.smtp.host");
		
		//get transport port
		String transportPortStr=this.ownerFaxClientSpi.getConfigurationValue("mail.smtp.port");
		this.transportPort=-1;
		if(transportPortStr!=null)
		{
			this.transportPort=Integer.parseInt(transportPortStr);
		}
	}
}